@@ -674,11 +674,18 @@ fn cmd_check_chain(ctx: &Context, cell_opts: &CellOptions) -> anyhow::Result<()>
         .chain_directory()
         .expect("Cell doesn't have a path configured");
 
-    print_spacer();
     let chain_config = config.chain.unwrap_or_default();
     let chain_store = DirectoryChainStore::create_or_open(chain_config.into(), &chain_dir)
         .expect("Couldn't open chain");
 
+    let last_block = chain_store
+        .get_last_block()
+        .expect("Couldn't get last block of chain")
+        .expect("Last block of chain is empty");
+
+    print_spacer();
+    let bar = indicatif::ProgressBar::new(last_block.get_height()?);
+
     let mut block_count = 0;
     for block in chain_store.blocks_iter(0) {
         let block = block?;
@@ -698,8 +705,12 @@ fn cmd_check_chain(ctx: &Context, cell_opts: &CellOptions) -> anyhow::Result<()>
             ));
             return Ok(());
         }
+
+        bar.set_position(block_count);
     }
 
+    bar.finish();
+
     print_success(format!(
         "Chain is valid. Analyzed {} blocks.",
         style_value(block_count)
@@ -1024,7 +1035,7 @@ async fn cmd_app_install(
     let mut cell_config =
         CellConfig::from_yaml_file(&config_path).expect("Couldn't read cell config");
 
-    let pkg = AppPackage::fetch_package_url(&install_opts.url)
+    let pkg = AppPackage::fetch_package_url(cell, &install_opts.url)
         .await
         .expect("Couldn't fetch app package");
     pkg.install(cell, &mut cell_config, install_opts.overwrite)
@@ -1094,7 +1105,7 @@ async fn unpack_cell_apps(
                     style_value(app.version)
                 ));
 
-                let pkg = AppPackage::fetch_package_url(&app.package_url)
+                let pkg = AppPackage::fetch_package_url(cell, &app.package_url)
                     .await
                     .expect("Couldn't fetch package");
 
